
#line 3 "lex.InstrScript_.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 39
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE InstrScript_restart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    /* Note: We specifically omit the test for yy_rule_can_match_eol because it requires
     *       access to the local variable yy_act. Since yyless() is a macro, it would break
     *       existing scanners that call yyless() from OUTSIDE InstrScript_lex. 
     *       One obvious solution it to make yy_act a global. I tried that, and saw
     *       a 5% performance hit in a non-yylineno scanner, because yy_act is
     *       normally declared as a register variable-- so it is not worth it.
     */
    #define  YY_LESS_LINENO(n) \
            do { \
                int yyl;\
                for ( yyl = n; yyl < yyleng; ++yyl )\
                    if ( yytext[yyl] == '\n' )\
                        --yylineno;\
            }while(0)
    #define YY_LINENO_REWIND_TO(dst) \
            do {\
                const char *p;\
                for ( p = yy_cp-1; p >= (dst); --p)\
                    if ( *p == '\n' )\
                        --yylineno;\
            }while(0)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via InstrScript_restart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void InstrScript_restart (FILE *input_file ,yyscan_t yyscanner );
void InstrScript__switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE InstrScript__create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void InstrScript__delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void InstrScript__flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void InstrScript_push_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void InstrScript_pop_buffer_state (yyscan_t yyscanner );

static void InstrScript_ensure_buffer_stack (yyscan_t yyscanner );
static void InstrScript__load_buffer_state (yyscan_t yyscanner );
static void InstrScript__init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER InstrScript__flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE InstrScript__scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE InstrScript__scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE InstrScript__scan_bytes (yyconst char *bytes,yy_size_t len ,yyscan_t yyscanner );

void *InstrScript_alloc (yy_size_t ,yyscan_t yyscanner );
void *InstrScript_realloc (void *,yy_size_t ,yyscan_t yyscanner );
void InstrScript_free (void * ,yyscan_t yyscanner );

#define yy_new_buffer InstrScript__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        InstrScript_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            InstrScript__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        InstrScript_ensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            InstrScript__create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define InstrScript_wrap(yyscanner) 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef int yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yy_fatal_error (yyconst char msg[] ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (size_t) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 51
#define YY_END_OF_BUFFER 52
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[642] =
    {   0,
       44,   44,   44,   44,    5,    5,    8,    8,   12,   12,
       13,   13,   17,   17,    0,    0,    0,    0,   52,   50,
       48,   46,   50,   41,   42,   43,   50,    2,   50,   41,
       41,   44,   44,   44,   44,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
       44,   50,   51,   51,   51,    6,    5,    5,    5,    5,
        5,   51,    9,    8,    8,    8,    8,    8,   12,   12,
       12,   12,   12,   13,   13,   13,   13,   13,   18,   17,
       17,   18,   18,   18,   18,   51,   14,   51,   51,   51,
       51,   51,   15,    0,    0,   48,   46,    0,    0,    1,

        0,   42,   42,   43,   43,    0,    3,    2,   44,   44,
       45,   35,   36,   44,   44,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   25,   44,   44,   44,   19,
       26,   44,   44,   44,   44,   44,   34,   44,    0,    0,
        0,   47,    0,    6,    5,    5,    5,    5,    5,    5,
        0,    9,    8,    8,    8,    8,    8,    8,   12,   12,
       12,   12,   12,   12,   13,   13,   13,   13,   13,   13,
       18,   18,   17,   17,   18,   18,   18,   18,    0,   14,
        0,    0,    0,    0,    0,   15,    1,    0,   42,   43,
       49,    3,   44,   44,   44,   44,   28,   44,   44,   44,

       44,   44,   20,   44,   44,   39,   29,   44,   44,   44,
       44,   44,   44,   47,    0,    5,    5,    5,    5,    8,
        8,    8,    8,   12,   12,   12,   12,   13,   13,   13,
       13,   18,   18,   18,   18,    0,    0,    0,    0,    0,
       42,   43,   44,   44,   44,   44,   44,   32,   44,   44,
       44,   30,   44,   22,   21,   44,   44,   44,   44,   40,
       44,    0,    5,    5,    5,    5,    8,    8,    8,    8,
       12,   12,   12,   12,   13,   13,   13,   13,   18,   18,
       18,   18,    0,    0,    0,    0,    0,   42,   43,   44,
       44,   44,   44,   37,   44,   44,   44,   44,   44,   44,

       44,   24,    0,    5,    5,    5,    5,    8,    8,    8,
        8,   12,   12,   12,   12,   13,   13,   13,   13,   18,
       18,   18,   18,    0,    0,    0,    0,    0,   42,   43,
       44,   44,   44,   44,   44,   44,   44,   44,   44,   44,
       33,    0,    5,    5,    5,    5,    8,    8,    8,    8,
       12,   12,   12,   12,   13,   13,   13,   13,   18,   18,
       18,   18,    0,    0,    0,    0,    0,   42,   43,   44,
       44,   44,   44,   44,   23,   44,   44,   44,   27,    0,
        5,    5,    5,    5,    8,    8,    8,    8,   12,   12,
       12,   12,   13,   13,   13,   13,   18,   18,   18,   18,

        0,    0,    0,    0,    0,   42,   43,   44,   44,   44,
       44,   44,   44,   44,    0,    5,    5,    5,    5,    8,
        8,    8,    8,   12,   12,   12,   12,   13,   13,   13,
       13,   18,   18,   18,   18,    0,    0,    0,    0,    0,
       42,   43,   44,   44,   44,   44,   44,   44,    0,    5,
        5,    5,    5,    8,    8,    8,    8,   12,   12,   12,
       12,   13,   13,   13,   13,   18,   18,   18,   18,    0,
        0,    0,    0,    0,   42,   43,   44,   44,   44,   44,
       31,   38,    0,    5,    5,    5,    5,    8,    8,    8,
        8,   12,   12,   12,   12,   13,   13,   13,   13,   18,

       18,   18,   18,    0,    0,    0,    0,    0,   42,   43,
       44,   44,   44,   44,    0,    5,    5,    5,    5,    8,
        8,    8,    8,   12,   12,   12,   12,   13,   13,   13,
       13,   18,   18,   18,   18,    0,    0,    0,    0,    0,
       42,   43,   16,   44,   44,    0,   10,   44,    0,    5,
        5,    5,    5,    8,    8,    8,    8,   12,   12,   12,
       12,   13,   13,   13,   13,   16,   18,   18,   18,   10,
       18,   16,    0,    0,    0,   16,   16,   16,   44,   44,
       44,   16,    5,    5,    5,    8,    8,    8,   12,   12,
       12,   13,   13,   13,   18,   18,   18,    0,    0,    0,

       44,    0,    4,   44,    5,    5,    8,    8,   12,   12,
       13,   13,   18,   18,    4,   18,    0,    0,   44,   44,
        5,    5,    8,    8,   12,   12,   13,   13,   18,   18,
        0,    0,    0,    7,    0,   11,   18,    7,   18,   11,
        0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    5,    6,    7,    8,    6,    1,    9,
       10,    6,    6,    6,    6,   11,    6,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   13,    1,   14,
       15,   16,    1,   17,   18,   18,   19,   20,   21,   22,
       18,   18,   23,   18,   18,   18,   18,   24,   25,   18,
       18,   26,   27,   28,   29,   18,   18,   18,   18,   18,
        6,    1,    6,    1,   30,    1,   31,   32,   33,   34,

       35,   36,   37,   38,   39,   18,   18,   40,   41,   42,
       43,   44,   18,   45,   46,   47,   48,   18,   49,   18,
       50,   18,   51,    1,   52,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[53] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1
    } ;

static yyconst flex_int16_t yy_base[657] =
    {   0,
        0,    0,    0,    0,   52,    0,  104,    0,  156,    0,
      208,    0,  259,  263,  272,  292,  301,  305, 1617, 1595,
      266, 1612,  276, 1593,  334,  386,  262,  438,  256,  257,
      285,  490, 1589, 1591, 1590, 1583, 1567, 1573,  233, 1572,
      270, 1558,  278, 1562, 1561,  311,  280, 1568, 1567,  253,
     1563,  354, 1579,  344, 1618, 1578,  542,  594,  337,  338,
      336,  362, 1577,  646,  698,  345,  346,  344,  750,  802,
      352,  353,  354,  854,  906,  358,  384,  385, 1576,  411,
      414,  398, 1575, 1574,  377,  454, 1573,  399, 1572, 1571,
      400,  455, 1570, 1569,  404,  456, 1586,  458, 1583, 1566,

      463,  958, 1562, 1010, 1561,  413,  312,  305,    0, 1560,
     1562, 1561, 1560, 1560,  402,  281, 1558, 1544, 1540, 1530,
     1533, 1541, 1527, 1538, 1529,    0, 1531, 1535, 1521,    0,
        0, 1527, 1523, 1525, 1524, 1528,    0, 1523,  464, 1509,
      509, 1539,  460, 1538, 1534,    0,  360, 1530, 1528,  409,
      472, 1534, 1530,    0,  411, 1526, 1524,  448, 1527,    0,
      489, 1523, 1521,  459, 1524,    0,  490, 1520, 1518,  494,
     1524,  496,  519,  522,  390,  507,  508, 1523,  517, 1522,
      544,  545,  546, 1521,  552, 1520, 1618,  609, 1520, 1519,
     1517,  556, 1507, 1515, 1505,  478,    0, 1495, 1498,  529,

     1492, 1496,    0, 1497, 1482,    0, 1493, 1477, 1493, 1490,
     1489, 1481, 1482, 1618,  568,  515,  557,  555, 1491,  556,
      563,  567, 1490,  589,  600,  592, 1489,  593,  604,  602,
     1488,  562, 1496,  606,  610,  612, 1495,  614,  644,  661,
     1485, 1484, 1484,  613, 1493, 1492, 1468,    0, 1462, 1463,
     1476,    0, 1459,    0,    0, 1461, 1469, 1472, 1469,    0,
     1466,  666,  412, 1472,  454,  619,  646, 1471,  652,  653,
      649, 1470,  660,  661,  657, 1469,  664,  670,  308,  696,
      467,  516,  561,  702,  671,  674,  724, 1467, 1466, 1467,
     1463, 1467, 1466,    0, 1447, 1444, 1449, 1449, 1452, 1439,

     1437,    0,  718,  701,  686,  707,  709,  711,  712,  716,
      719,  745,  738,  749,  751,  753,  754,  757,  761,  762,
      628,  766,  767,  769,  716,  772,  773,  817, 1456, 1455,
     1460, 1461, 1455, 1458, 1437, 1441, 1432, 1431, 1425, 1437,
        0,  821,  804,  776, 1447,  807,  808,  811, 1446,  813,
      815,  821, 1445,  823,  825,  833, 1444,  852, 1446,  858,
      857,  830, 1445,  861,  862,  864,  888, 1444, 1443,  775,
     1438, 1442, 1440, 1420,    0, 1417, 1416, 1412,    0,  897,
     1426,  863,  870,  868, 1425,  871,  877,  878, 1424,  879,
      904,  905, 1423,  907,  913,  914,  915,  919,  921, 1431,

      922,  926,  933, 1430,  973,  926,  931, 1431, 1425, 1425,
      953, 1412, 1407, 1410,  977,  962, 1420,  961, 1413,  963,
     1418,  965, 1411,  971, 1416,  968, 1409,  980, 1414,  982,
     1407,  981,  972, 1007, 1011, 1015, 1016, 1021, 1022, 1044,
     1417, 1416, 1409, 1413, 1404, 1408, 1385, 1396, 1035, 1026,
     1033, 1031, 1043, 1044, 1040, 1046, 1048, 1051, 1053, 1054,
     1056, 1059, 1061, 1062, 1065, 1070, 1072,  793, 1073, 1076,
     1078,  813, 1079, 1100, 1403, 1402, 1406, 1402, 1401, 1401,
        0,    0, 1101, 1086, 1084, 1088, 1091, 1094, 1093, 1096,
     1105, 1104, 1107, 1109, 1112, 1115, 1114, 1117, 1120, 1125,

     1126, 1127, 1130, 1134, 1135, 1136, 1139, 1159, 1389, 1388,
     1383, 1375, 1376, 1161, 1162, 1024, 1143, 1144, 1164, 1151,
     1150, 1152, 1183, 1160, 1162, 1171, 1191, 1177, 1175, 1180,
     1200, 1379, 1189, 1187, 1214, 1378, 1190, 1201, 1218, 1226,
     1376, 1371, 1365, 1355, 1351, 1231, 1351, 1339, 1216,    0,
     1218, 1316, 1292,    0, 1222, 1291, 1258,    0, 1226, 1227,
     1214,    0, 1230, 1182, 1173, 1204, 1166, 1234, 1254, 1122,
     1236, 1238, 1211, 1240, 1245, 1262, 1099, 1085, 1033, 1234,
     1014, 1267, 1247, 1271, 1252, 1254, 1272, 1260, 1265, 1285,
     1268, 1273, 1297, 1276, 1282, 1302, 1287, 1289, 1311, 1297,

     1009, 1315, 1001,  985,  984, 1301,  946, 1302,  924, 1303,
      910, 1309, 1281, 1326,  904, 1313, 1318, 1317, 1341, 1342,
     1344, 1346, 1347, 1350, 1352, 1355, 1356, 1358, 1360, 1364,
     1375, 1381, 1384,  877, 1385,  853, 1386,  845, 1389,  758,
     1618, 1410, 1412,  747, 1414,  700,  638,  605, 1416,  559,
      470,  388,  351,  268, 1418, 1420
    } ;

static yyconst flex_int16_t yy_def[657] =
    {   0,
      641,    1,    1,    1,  641,    5,  641,    7,  641,    9,
      641,   11,  642,  642,  643,  643,  643,  643,  641,  644,
      644,  641,  645,  644,  646,  647,  644,  648,  644,  644,
      644,  648,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,  649,  644,  644,  641,  644,  650,  650,   58,   58,
       58,  644,  644,  651,  651,   65,   65,   65,  652,  652,
       70,   70,   70,  653,  653,   75,   75,   75,  654,  654,
      641,  654,  654,  654,  654,  644,  644,  644,  644,  644,
      644,  644,  644,  644,  644,  644,  641,  645,  655,  644,

      645,  646,  102,  647,  104,  644,  644,   32,   32,   32,
      644,  644,  644,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,  649,  656,
      649,  644,  644,  644,   58,   58,   58,   58,   58,   58,
      644,  644,   65,   65,   65,   65,   65,   65,   70,   70,
       70,   70,   70,   70,   75,   75,   75,   75,   75,   75,
      654,  654,  654,  641,  654,  654,  654,  654,  644,  644,
      644,  644,  644,  644,  644,  644,  641,  645,  102,  104,
      644,  644,   32,   32,   32,   32,   32,   32,   32,   32,

       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,  641,  649,   58,   58,   58,   58,   65,
       65,   65,   65,   70,   70,   70,   70,   75,   75,   75,
       75,  654,  654,  654,  654,  644,  644,  644,  644,  645,
      102,  104,   32,   32,   32,   32,   32,   32,   32,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,  649,   58,   58,   58,   58,   65,   65,   65,   65,
       70,   70,   70,   70,   75,   75,   75,   75,  654,  654,
      654,  654,  644,  644,  644,  644,  645,  102,  104,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,

       32,   32,  649,   58,   58,   58,   58,   65,   65,   65,
       65,   70,   70,   70,   70,   75,   75,   75,   75,  654,
      654,  654,  654,  644,  644,  644,  644,  645,  102,  104,
       32,   32,   32,   32,   32,   32,   32,   32,   32,   32,
       32,  649,   58,   58,   58,   58,   65,   65,   65,   65,
       70,   70,   70,   70,   75,   75,   75,   75,  654,  654,
      654,  654,  644,  644,  644,  644,  645,  102,  104,   32,
       32,   32,   32,   32,   32,   32,   32,   32,   32,  649,
       58,   58,   58,   58,   65,   65,   65,   65,   70,   70,
       70,   70,   75,   75,   75,   75,  654,  654,  654,  654,

      644,  644,  644,  644,  645,  102,  104,   32,   32,   32,
       32,   32,   32,   32,  649,   58,   58,   58,   58,   65,
       65,   65,   65,   70,   70,   70,   70,   75,   75,   75,
       75,  654,  654,  654,  654,  644,  644,  644,  644,  645,
      102,  104,   32,   32,   32,   32,   32,   32,  649,   58,
       58,   58,   58,   65,   65,   65,   65,   70,   70,   70,
       70,   75,   75,   75,   75,  654,  654,  654,  654,  644,
      644,  644,  644,  645,  102,  104,   32,   32,   32,   32,
       32,   32,  649,   58,   58,   58,   58,   65,   65,   65,
       65,   70,   70,   70,   70,   75,   75,   75,   75,  654,

      654,  654,  654,  644,  644,  644,  644,  645,  102,  104,
       32,   32,   32,   32,  649,   58,   58,   58,   58,   65,
       65,   65,   65,   70,   70,   70,   70,   75,   75,   75,
       75,  654,  654,  654,  654,  644,  644,  644,  644,  645,
      102,  104,   32,   32,   32,  644,  644,   32,  649,   58,
       58,   58,   58,   65,   65,   65,   65,   70,   70,   70,
       70,   75,   75,   75,   75,  654,  654,  654,  654,  654,
      654,  644,  644,  644,  644,  645,  102,  104,   32,   32,
       32,  649,   58,   58,   58,   65,   65,   65,   70,   70,
       70,   75,   75,   75,  654,  654,  654,  644,  644,  644,

       32,  644,  644,   32,   58,   58,   65,   65,   70,   70,
       75,   75,  654,  654,  654,  654,  644,  644,   32,   32,
       58,   58,   65,   65,   70,   70,   75,   75,  654,  654,
      644,  644,  644,  644,  644,  644,  654,  654,  654,  654,
        0,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641
    } ;

static yyconst flex_int16_t yy_nxt[1671] =
    {   0,
       20,   21,   22,   21,   23,   24,   25,   26,   24,   24,
       27,   28,   29,   30,   24,   31,   25,   32,   32,   32,
       33,   32,   32,   32,   32,   34,   35,   32,   36,   32,
       37,   38,   39,   40,   41,   42,   32,   32,   43,   32,
       44,   45,   46,   47,   48,   49,   50,   32,   51,   32,
       52,   20,   53,   54,   55,   53,   53,   53,   53,   53,
       53,   56,   53,   57,   53,   53,   53,   53,   53,   57,
       57,   57,   58,   57,   57,   57,   57,   59,   60,   57,
       61,   57,   57,   57,   57,   57,   57,   57,   57,   57,
       57,   57,   57,   57,   57,   57,   57,   57,   57,   57,

       57,   57,   53,   53,   53,   62,   55,   53,   53,   53,
       53,   53,   53,   63,   53,   64,   53,   53,   53,   53,
       53,   64,   64,   64,   65,   64,   64,   64,   64,   66,
       67,   64,   68,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   53,   53,   53,   53,   55,   53,
       53,   53,   53,   53,   53,   53,   53,   69,   53,   53,
       53,   53,   53,   69,   69,   69,   70,   69,   69,   69,
       69,   71,   72,   69,   73,   69,   69,   69,   69,   69,
       69,   69,   69,   69,   69,   69,   69,   69,   69,   69,

       69,   69,   69,   69,   69,   69,   53,   53,   53,   53,
       55,   53,   53,   53,   53,   53,   53,   53,   53,   74,
       53,   53,   53,   53,   53,   74,   74,   74,   75,   74,
       74,   74,   74,   76,   77,   74,   78,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   74,   74,
       74,   74,   74,   74,   74,   74,   74,   74,   53,   53,
       80,   81,   80,  120,   80,   81,   80,   96,  171,   96,
      111,  112,  106,   86,   55,  121,   95,   95,   99,   82,
      100,   87,   95,   82,   83,   84,   95,   85,   83,   84,
      136,   85,   88,   86,   55,  137,  101,   89,   90,  113,

       91,   87,   92,   55,  114,   95,   92,   55,  195,  123,
       93,  124,   88,  126,   93,  107,  108,   89,   90,  127,
       91,   88,  132,  192,  133,   88,   89,   90,  172,   91,
       89,   90,   95,   91,   94,   94,  320,   94,   94,   94,
       94,   94,   94,   94,   94,  143,   94,   94,   94,   94,
       94,  165,  130,  144,  103,  131,  140,  148,  149,  145,
      145,  145,  150,  151,   95,  156,  157,  153,  153,  153,
      158,  152,  162,  163,  141,  159,  159,  159,  168,  216,
      164,  165,   95,  145,   94,   94,   94,   94,  159,   94,
       94,   94,   94,   94,   94,   94,   94,  172,   94,   94,

       94,   94,   94,  178,  169,  142,  105,  165,  165,  232,
      172,  170,  173,  174,  173,  174,  174,  174,  172,   95,
       95,  175,  181,  191,   95,  114,  184,  181,  194,  219,
      220,  172,  145,   95,  153,  145,   94,   94,   94,   94,
      304,   94,   94,   94,   94,   94,   94,   94,  107,  108,
       94,   94,   94,   94,   94,  179,  185,   96,  110,   96,
       99,  143,  100,  180,  186,   99,  140,  100,  223,  144,
      153,  153,  306,  151,   95,   95,   95,  145,  101,  227,
       95,  152,  159,  101,  141,  322,  188,  172,   94,   94,
       94,   94,   95,   94,   94,   94,   94,   94,   94,   94,

       94,  114,   94,   94,   94,   94,   94,  246,  224,  228,
      110,  140,  159,  165,  231,  142,  172,  165,  179,  175,
      173,  174,  173,  174,  174,  174,  180,  172,  172,  141,
      175,  175,  215,  233,  323,  234,  172,   95,  145,  172,
       94,   94,   94,   94,  263,   94,   94,   94,   94,   94,
       94,   94,   94,  185,   94,   94,   94,   94,   94,  145,
      142,  186,  146,  236,   95,   95,   95,  192,  181,  181,
      140,  237,   95,  238,  249,  250,   95,  264,  145,  153,
      145,   95,  172,  268,  265,  267,  153,  262,  141,  324,
      153,  279,   94,   94,   94,   94,  269,   94,   94,   94,

       94,   94,   94,   94,   94,  109,   94,   94,   94,   94,
       94,   99,  159,  100,  146,  159,  165,  147,  271,  142,
      272,  273,  275,  159,  276,  165,  172,  165,  240,  101,
      172,  277,   95,  175,   95,  281,  114,  307,  104,  282,
      291,  283,  145,  285,   94,   94,   94,   94,  172,   94,
       94,   94,   94,   94,   94,   94,   94,  360,   94,   94,
       94,   94,   94,   99,   95,  100,  154,  181,  140,  153,
      310,  311,  159,  286,  308,  153,  153,  312,  314,  315,
      165,  101,  318,  159,  159,  316,  141,  165,  319,  326,
      287,   95,  327,  165,   95,  303,   94,   94,   94,   94,

      102,   94,   94,   94,   94,   94,   94,   94,   94,  145,
       94,   94,   94,   94,   94,  344,  172,  142,  154,  175,
      140,  155,   95,  321,  145,  181,   99,  343,  100,  325,
      145,  345,  145,  346,  153,  153,   95,  347,  141,  153,
      349,  348,  153,  350,  101,  364,  342,   94,   94,   94,
       94,   94,  328,   94,   94,   94,   94,   94,   94,   94,
       94,  159,   94,   94,   94,   94,   94,  352,  159,  142,
      160,  351,  159,  353,  159,  354,  165,  165,  172,  355,
      165,  357,  172,  356,  165,  358,  172,  172,  359,   95,
      361,  362,   95,   95,  382,  363,  365,  366,  114,  145,

       94,   94,   94,   94,  408,   94,   94,   94,   94,   94,
       94,   94,   94,  172,   94,   94,   94,   94,   94,   99,
      502,  100,  160,  140,  381,  161,  384,  145,  385,  386,
      145,  153,  388,   95,  153,  389,  153,  101,  159,  390,
      506,  141,  392,  367,  159,  393,  159,  380,  165,  400,
      172,  394,   94,   94,   94,   94,  165,   94,   94,   94,
       94,   94,   94,   94,   94,  172,   94,   94,   94,   94,
       94,  396,  142,   95,  166,  165,  398,  172,  172,  402,
      399,   95,   95,  404,   95,  403,  145,  417,  419,  418,
       99,  145,  100,  145,  153,  421,  422,   95,  423,  140,

      153,  153,  159,  425,   94,   94,   94,   94,  405,   94,
       94,   94,   94,   94,   94,   94,   94,  415,   94,   94,
       94,   94,   94,  426,  172,  427,  166,  159,  159,  167,
      165,  429,  430,  627,  431,  172,  165,  165,  175,  172,
      434,  172,   95,  433,  432,  181,   95,  625,  142,  189,
      437,  436,  438,   95,  190,  441,   94,   94,   94,   94,
      442,   94,   94,   94,   94,   94,   94,   94,   94,  623,
       94,   94,   94,   94,   94,   99,  114,  100,  103,  140,
      450,  454,  446,  452,  145,  145,  153,  456,  153,  458,
      460,  159,  172,  101,  159,  467,  188,  141,  462,  466,

      215,  172,  440,  165,  464,  165,  449,  621,   94,   94,
       94,   94,  620,   94,   94,   94,   94,   94,   94,   94,
       94,   95,   94,   94,   94,   94,   94,  172,  142,  468,
      105,  172,  619,  470,  175,   95,   95,  140,  604,  471,
      469,   95,   95,  472,  550,  181,   99,  145,  100,  145,
      484,  473,  485,  483,  145,  141,  145,  601,  486,  489,
       94,   94,  474,  153,  101,  487,  145,  153,  488,  153,
      491,  153,  493,  490,  159,  492,  159,  159,  495,  159,
      497,  494,  165,  496,  165,  165,  142,  499,  165,  498,
      172,  501,  172,  172,  500,  503,   95,  505,   95,   95,

      504,  507,   99,  140,  100,  516,  517,  145,  190,  145,
      518,  145,  519,  520,  145,  521,  153,  153,  522,  153,
      101,  141,  189,  524,  508,  515,  523,  159,  153,  525,
      159,  526,  159,  527,  528,  159,  529,  165,  165,  530,
      165,  531,  172,  165,  532,  172,  172,  172,  533,  534,
      172,  535,  142,  536,   95,   95,   95,  537,  538,   95,
      539,   99,  546,  100,  140,  546,  145,  145,  552,  547,
      551,  554,  547,  153,  153,  153,  556,  555,  540,  101,
      558,  549,  141,  159,  546,  159,  172,  145,  595,  559,
      548,  547,  546,  553,  159,  560,  594,  562,  165,  547,

      165,  546,  563,  165,  564,  593,  153,  172,  547,  172,
       95,  568,  557,  142,  159,  569,  567,  573,  140,  546,
      561,   95,  570,  165,  172,  574,  547,  175,   99,  565,
      100,   95,  546,  598,  172,  602,  582,  591,   95,  547,
      583,  145,  603,  571,  586,  153,  576,  575,  589,  159,
      590,   95,  592,  165,  172,  569,  172,  596,   95,  597,
       95,  181,  570,  599,   99,   95,  100,  142,  600,  140,
      145,  605,  602,  602,  172,  145,  606,  153,  607,  603,
      603,  588,  101,  153,  608,  188,  602,  141,  159,  609,
      215,  159,  610,  603,  145,  153,  165,  611,  602,  165,

      612,  172,  172,  614,  629,  603,  613,  172,  159,   95,
      615,  616,  602,  617,  587,  585,  602,   95,  142,  603,
      165,  618,  172,  603,  145,  153,  159,  614,  622,  624,
      626,   95,  165,  172,  615,   95,  628,   95,   95,  584,
      630,  631,  633,  635,  632,  633,  172,  635,  633,  634,
      636,  635,  634,  633,  636,  634,  635,  633,  636,  635,
      634,  637,  581,  636,  634,  639,  636,  145,  638,  145,
      153,   95,  640,  153,  580,  159,  633,  579,  159,  165,
      172,  165,  635,  634,  172,  633,  635,  637,  114,  636,
      639,  578,  634,  636,  638,   95,  577,  640,  572,  566,

      545,   95,  544,  543,   95,   95,  172,  542,  541,  172,
       79,   79,   53,   53,   98,   98,  139,  139,   99,   99,
      140,  140,  514,  513,  512,  511,  510,  509,  482,  481,
      480,  479,  478,  477,  476,  475,  465,  463,  461,  459,
      457,  455,  453,  451,  260,  448,  447,  445,  444,  443,
      439,  435,  428,  424,  420,  416,  414,  413,  260,  412,
      411,  410,  409,  407,  406,  401,  397,  395,  391,  387,
      383,  379,  378,  377,  376,  375,  374,  373,  372,  371,
      370,  369,  368,  341,  340,  339,  338,  337,  336,  335,
      334,  333,  332,  331,  330,  329,  317,  313,  309,  305,

      302,  301,  300,  299,  298,  297,  296,  295,  294,  260,
      293,  292,  290,  289,  288,  284,  280,  278,  274,  270,
      266,  261,  260,  259,  258,  257,  256,  255,  254,  253,
      252,  251,  248,  247,  245,  244,  243,   95,  242,  241,
       95,  239,   95,  235,  172,  230,  229,  165,  226,  225,
      159,  222,  221,  153,   95,  218,  217,  145,   95,   95,
      214,  213,  212,  211,  210,  209,  208,  207,  206,  205,
      204,  203,  202,  201,  200,  199,  198,  197,  196,  193,
       95,   95,   95,  114,  190,  189,   95,  187,   97,   95,
       95,  183,  182,   95,  177,  176,  172,   95,   95,   95,

      138,  135,  134,  129,  128,  125,  122,  119,  118,  117,
      116,  115,  114,   95,   97,   95,  641,   19,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641
    } ;

static yyconst flex_int16_t yy_chk[1671] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    5,    5,    5,    5,

        5,    5,    5,    5,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    9,    9,    9,

        9,    9,    9,    9,    9,    9,    9,    9,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       13,   13,   13,   39,   14,   14,   14,   21,  654,   21,
       29,   30,   27,   15,   15,   39,   29,   30,   23,   13,
       23,   15,   27,   14,   13,   13,   21,   13,   14,   14,
       50,   14,   15,   16,   16,   50,   23,   15,   15,   31,

       15,   16,   17,   17,  116,   31,   18,   18,  116,   41,
       17,   41,   16,   43,   18,  108,  108,   16,   16,   43,
       16,   17,   47,  107,   47,   18,   17,   17,  279,   17,
       18,   18,  107,   18,   25,   25,  279,   25,   25,   25,
       25,   25,   25,   25,   25,   54,   25,   25,   25,   25,
       25,  653,   46,   54,   25,   46,   52,   59,   60,   61,
       59,   60,   61,   62,   54,   66,   67,   68,   66,   67,
       68,   62,   71,   72,   52,   71,   72,   73,   76,  147,
       73,   76,   62,  147,   25,   25,   26,   26,  652,   26,
       26,   26,   26,   26,   26,   26,   26,   85,   26,   26,

       26,   26,   26,   85,   77,   52,   26,   77,   78,  175,
      175,   78,   80,   80,   80,   81,   81,   81,   82,   88,
       91,   82,   88,  106,   95,  115,   91,   95,  115,  150,
      155,   80,  150,  106,  155,  263,   26,   26,   28,   28,
      263,   28,   28,   28,   28,   28,   28,   28,   28,   28,
       28,   28,   28,   28,   28,   86,   92,   96,   28,   96,
       98,  143,   98,   86,   92,  101,  139,  101,  158,  143,
      651,  158,  265,  151,   86,   92,   96,  265,   98,  164,
      143,  151,  164,  101,  139,  281,  101,  281,   28,   28,
       32,   32,  151,   32,   32,   32,   32,   32,   32,   32,

       32,  196,   32,   32,   32,   32,   32,  196,  161,  167,
       32,  141,  161,  167,  170,  139,  172,  170,  179,  172,
      173,  173,  173,  174,  174,  174,  179,  176,  177,  141,
      176,  177,  141,  176,  282,  177,  282,  179,  216,  173,
       32,   32,   57,   57,  216,   57,   57,   57,   57,   57,
       57,   57,   57,  185,   57,   57,   57,   57,   57,  650,
      141,  185,   57,  181,  181,  182,  183,  192,  182,  183,
      215,  182,  185,  183,  200,  200,  192,  217,  218,  220,
      217,  283,  232,  221,  218,  220,  221,  215,  215,  283,
      222,  232,   57,   57,   58,   58,  222,   58,   58,   58,

       58,   58,   58,   58,   58,  648,   58,   58,   58,   58,
       58,  188,  224,  188,   58,  226,  228,   58,  224,  215,
      225,  226,  228,  225,  229,  230,  234,  229,  188,  188,
      235,  230,  236,  235,  238,  234,  244,  266,  647,  235,
      244,  236,  266,  238,   58,   58,   64,   64,  321,   64,
       64,   64,   64,   64,   64,   64,   64,  321,   64,   64,
       64,   64,   64,  240,  239,  240,   64,  239,  262,  267,
      269,  270,  271,  239,  267,  269,  270,  271,  273,  274,
      275,  240,  277,  273,  274,  275,  262,  277,  278,  285,
      240,  285,  286,  278,  286,  262,   64,   64,   65,   65,

      646,   65,   65,   65,   65,   65,   65,   65,   65,  305,
       65,   65,   65,   65,   65,  305,  280,  262,   65,  280,
      303,   65,  284,  280,  304,  284,  287,  304,  287,  284,
      306,  306,  307,  307,  308,  309,  325,  308,  303,  310,
      310,  309,  311,  311,  287,  325,  303,  644,   65,   65,
       69,   69,  287,   69,   69,   69,   69,   69,   69,   69,
       69,  313,   69,   69,   69,   69,   69,  313,  312,  303,
       69,  312,  314,  314,  315,  315,  316,  317,  640,  316,
      318,  318,  320,  317,  319,  319,  322,  323,  320,  324,
      322,  323,  326,  327,  344,  324,  326,  327,  370,  344,

       69,   69,   70,   70,  370,   70,   70,   70,   70,   70,
       70,   70,   70,  468,   70,   70,   70,   70,   70,  328,
      468,  328,   70,  342,  343,   70,  346,  343,  347,  348,
      346,  347,  350,  472,  348,  351,  350,  328,  351,  352,
      472,  342,  354,  328,  352,  355,  354,  342,  355,  362,
      362,  356,   70,   70,   74,   74,  356,   74,   74,   74,
       74,   74,   74,   74,   74,  638,   74,   74,   74,   74,
       74,  358,  342,  636,   74,  358,  360,  361,  360,  364,
      361,  364,  365,  366,  366,  365,  382,  382,  384,  383,
      367,  384,  367,  383,  386,  386,  387,  634,  388,  380,

      387,  388,  390,  390,   74,   74,   75,   75,  367,   75,
       75,   75,   75,   75,   75,   75,   75,  380,   75,   75,
       75,   75,   75,  391,  615,  392,   75,  391,  392,   75,
      394,  394,  395,  611,  396,  397,  395,  396,  397,  398,
      399,  399,  401,  398,  397,  401,  402,  609,  380,  406,
      402,  401,  403,  403,  407,  406,   75,   75,  102,  102,
      407,  102,  102,  102,  102,  102,  102,  102,  102,  607,
      102,  102,  102,  102,  102,  405,  411,  405,  102,  415,
      416,  420,  411,  418,  418,  416,  420,  422,  422,  424,
      426,  426,  433,  405,  424,  433,  405,  415,  428,  432,

      415,  432,  405,  428,  430,  430,  415,  605,  102,  102,
      104,  104,  604,  104,  104,  104,  104,  104,  104,  104,
      104,  603,  104,  104,  104,  104,  104,  434,  415,  434,
      104,  435,  601,  436,  435,  436,  437,  449,  581,  437,
      435,  438,  439,  438,  516,  439,  440,  516,  440,  450,
      450,  439,  451,  449,  452,  449,  451,  579,  452,  455,
      104,  104,  440,  455,  440,  453,  453,  454,  454,  456,
      457,  457,  459,  456,  458,  458,  459,  460,  461,  461,
      463,  460,  462,  462,  463,  464,  449,  465,  465,  464,
      466,  467,  467,  469,  466,  469,  470,  471,  471,  473,

      470,  473,  474,  483,  474,  484,  485,  485,  578,  484,
      486,  486,  487,  488,  487,  489,  489,  488,  490,  490,
      474,  483,  577,  492,  474,  483,  491,  492,  491,  493,
      493,  494,  494,  495,  496,  495,  497,  497,  496,  498,
      498,  499,  570,  499,  500,  500,  501,  502,  501,  502,
      503,  503,  483,  504,  504,  505,  506,  505,  506,  507,
      507,  508,  514,  508,  515,  519,  517,  518,  518,  514,
      517,  520,  519,  521,  520,  522,  522,  521,  508,  508,
      524,  515,  515,  524,  523,  525,  567,  519,  567,  525,
      514,  523,  527,  519,  526,  526,  565,  528,  529,  527,

      528,  531,  529,  530,  530,  564,  523,  534,  531,  533,
      537,  534,  523,  515,  527,  535,  533,  537,  549,  539,
      527,  538,  535,  531,  566,  538,  539,  566,  540,  531,
      540,  573,  546,  573,  535,  580,  549,  561,  539,  546,
      551,  551,  580,  535,  555,  555,  540,  539,  559,  559,
      560,  546,  563,  563,  568,  569,  571,  568,  572,  571,
      574,  572,  569,  574,  576,  575,  576,  549,  575,  582,
      583,  583,  584,  587,  569,  585,  585,  586,  586,  584,
      587,  557,  576,  588,  588,  576,  590,  582,  589,  589,
      582,  591,  591,  590,  584,  587,  592,  592,  593,  594,

      594,  613,  595,  596,  613,  593,  595,  597,  590,  598,
      596,  597,  599,  598,  556,  553,  602,  600,  582,  599,
      593,  600,  596,  602,  606,  608,  610,  614,  606,  608,
      610,  599,  612,  616,  614,  602,  612,  618,  617,  552,
      616,  617,  619,  620,  618,  621,  614,  622,  623,  619,
      620,  624,  621,  625,  622,  623,  626,  627,  624,  628,
      625,  629,  548,  626,  627,  630,  628,  621,  629,  622,
      623,  547,  630,  624,  545,  625,  631,  544,  626,  627,
      629,  628,  632,  631,  630,  633,  635,  637,  543,  632,
      639,  542,  633,  635,  637,  631,  541,  639,  536,  532,

      513,  632,  512,  511,  633,  635,  637,  510,  509,  639,
      642,  642,  643,  643,  645,  645,  649,  649,  655,  655,
      656,  656,  480,  479,  478,  477,  476,  475,  448,  447,
      446,  445,  444,  443,  442,  441,  431,  429,  427,  425,
      423,  421,  419,  417,  414,  413,  412,  410,  409,  408,
      404,  400,  393,  389,  385,  381,  378,  377,  376,  374,
      373,  372,  371,  369,  368,  363,  359,  357,  353,  349,
      345,  340,  339,  338,  337,  336,  335,  334,  333,  332,
      331,  330,  329,  301,  300,  299,  298,  297,  296,  295,
      293,  292,  291,  290,  289,  288,  276,  272,  268,  264,

      261,  259,  258,  257,  256,  253,  251,  250,  249,  247,
      246,  245,  243,  242,  241,  237,  233,  231,  227,  223,
      219,  213,  212,  211,  210,  209,  208,  207,  205,  204,
      202,  201,  199,  198,  195,  194,  193,  191,  190,  189,
      186,  184,  180,  178,  171,  169,  168,  165,  163,  162,
      159,  157,  156,  153,  152,  149,  148,  145,  144,  142,
      140,  138,  136,  135,  134,  133,  132,  129,  128,  127,
      125,  124,  123,  122,  121,  120,  119,  118,  117,  114,
      113,  112,  111,  110,  105,  103,  100,   99,   97,   94,
       93,   90,   89,   87,   84,   83,   79,   63,   56,   53,

       51,   49,   48,   45,   44,   42,   40,   38,   37,   36,
       35,   34,   33,   24,   22,   20,   19,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641,
      641,  641,  641,  641,  641,  641,  641,  641,  641,  641
    } ;

/* Table of booleans, true if rule could match eol. */
static yyconst flex_int32_t yy_rule_can_match_eol[52] =
    {   0,
1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 
    0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
    0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0,     };

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scanner.l"
/*
 * Copyright (c) 2014 Christian Schoenebeck and Andreas Persson
 *
 * http://www.linuxsampler.org
 *
 * This file is part of LinuxSampler and released under the same terms.
 * See README file for details.
 */
/* Token scanner for instrument script language. */
/* FIXME: line numbers (i.e. on error/warning messages) are incorrect, because
   the current grammar does not process new line characters. \n is currently
   filtered out in this lexer. Due to this, the parser will sometimes read
   several lines before it matches the next complete grammar rule, causing the
   incorrect lines in the error/warning messages. */
#line 19 "scanner.l"

#include "parser_shared.h"
#include <math.h>
// reentrant scanner data context
#define YY_EXTRA_TYPE ParserContext*
// set line number each time a token is recognized
#define YY_USER_ACTION                  \
{                                       \
    yylloc->first_line = yylineno;      \
    yylloc->last_line  = yylineno;      \
    /* first_column = TODO */           \
    /* last_column  = TODO */           \
    /*printf("lex: line '%s'\n", yytext);*/  \
}
// custom (f)lex input for reading from std::istream object
#define YY_INPUT(buf,result,max_size)   \
{                                       \
    char c = yyextra->is->get();        \
    if (yyextra->is->eof())             \
        result = YY_NULL;               \
    else {                              \
        buf[0] = c;                     \
        result = 1;                     \
    }                                   \
}

static void scanner_error(YYLTYPE* locp, LinuxSampler::ParserContext* context, const char* err) {
    context->addErr(locp->first_line, err);
}

static void scanner_warning(YYLTYPE* locp, LinuxSampler::ParserContext* context, const char* txt) {
    context->addWrn(locp->first_line, txt);
}

#define SCANNER_ERR(txt)  scanner_error(yylloc, yyextra, txt)
#define SCANNER_WRN(txt)  scanner_warning(yylloc, yyextra, txt)

using namespace LinuxSampler;

/* use Flex's built-in support for line numbers */
/* generate a reentrant safe scanner */
/* avoid symbol collision with other (i.e. future) scanner symbols */
/* bison-bridge adds an argument yylval to InstrScript_lex, and bison-locations adds an
   argument code yylloc for location tracking. */
/* InstrScript_wrap() would be called at EOF, we don't need it */
/* enable functions yy_push_state(), yy_pop_state(), yy_top_state() */
/* inclusive scanner conditions */

/* exclusive scanner conditions */

#line 1113 "lex.InstrScript_.c"

#define INITIAL 0
#define PREPROC_BODY_USE 1
#define PREPROC_SET_COND 2
#define PREPROC_RESET_COND 3
#define PREPROC_IF 4
#define PREPROC_IF_NOT 5
#define PREPROC_BODY_EAT 6
#define PREPROC_PRE_BODY_USE 7
#define PREPROC_PRE_BODY_EAT 8

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    yy_size_t yy_n_chars;
    yy_size_t yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int InstrScript_lex_init (yyscan_t* scanner);

int InstrScript_lex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int InstrScript_lex_destroy (yyscan_t yyscanner );

int InstrScript_get_debug (yyscan_t yyscanner );

void InstrScript_set_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE InstrScript_get_extra (yyscan_t yyscanner );

void InstrScript_set_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *InstrScript_get_in (yyscan_t yyscanner );

void InstrScript_set_in  (FILE * in_str ,yyscan_t yyscanner );

FILE *InstrScript_get_out (yyscan_t yyscanner );

void InstrScript_set_out  (FILE * out_str ,yyscan_t yyscanner );

yy_size_t InstrScript_get_leng (yyscan_t yyscanner );

char *InstrScript_get_text (yyscan_t yyscanner );

int InstrScript_get_lineno (yyscan_t yyscanner );

void InstrScript_set_lineno (int line_number ,yyscan_t yyscanner );

int InstrScript_get_column  (yyscan_t yyscanner );

void InstrScript_set_column (int column_no ,yyscan_t yyscanner );

YYSTYPE * InstrScript_get_lval (yyscan_t yyscanner );

void InstrScript_set_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *InstrScript_get_lloc (yyscan_t yyscanner );
    
        void InstrScript_set_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int InstrScript_wrap (yyscan_t yyscanner );
#else
extern int InstrScript_wrap (yyscan_t yyscanner );
#endif
#endif

    static void yyunput (int c,char *buf_ptr  ,yyscan_t yyscanner);
    
#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

    static void yy_push_state (int new_state ,yyscan_t yyscanner);
    
    static void yy_pop_state (yyscan_t yyscanner );
    
    static int yy_top_state (yyscan_t yyscanner );
    
/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, yyin))==0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int InstrScript_lex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int InstrScript_lex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			InstrScript_ensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				InstrScript__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		InstrScript__load_buffer_state(yyscanner );
		}

	{
#line 83 "scanner.l"


#line 1411 "lex.InstrScript_.c"

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yyg->yy_start;
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				yyg->yy_last_accepting_state = yy_current_state;
				yyg->yy_last_accepting_cpos = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 642 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1618 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

		if ( yy_act != YY_END_OF_BUFFER && yy_rule_can_match_eol[yy_act] )
			{
			yy_size_t yyl;
			for ( yyl = 0; yyl < yyleng; ++yyl )
				if ( yytext[yyl] == '\n' )
					   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;
			}

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = yyg->yy_hold_char;
			yy_cp = yyg->yy_last_accepting_cpos;
			yy_current_state = yyg->yy_last_accepting_state;
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 85 "scanner.l"
{
    yylval->sValue = strdup(yytext + 1);
    yylval->sValue[strlen(yylval->sValue) - 1] = '\0';
    return STRING;
}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 91 "scanner.l"
{
    yylval->iValue = atoi(yytext);
    return INTEGER;
}
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 96 "scanner.l"
{
    printf("A float: %s (%g)\n", yytext, atof(yytext));
}
	YY_BREAK
/* Preprocessor statement:  SET_CONDITION(name) */
case 4:
YY_RULE_SETUP
#line 103 "scanner.l"
{
    //printf("SET_CONDITION\n");
    yy_push_state(PREPROC_SET_COND, yyscanner);
}
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 107 "scanner.l"
{
    //printf("preproc set condition '%s'\n", yytext);
    bool success = yyextra->setPreprocessorCondition(yytext);
    if (!success) {
        SCANNER_WRN((String("Preprocessor: Condition '") +
                    yytext + "' is already set.").c_str());
    }
}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 115 "scanner.l"
{
    //printf("End of PREPROC_SET_COND\n");
    yy_pop_state(yyscanner);
}
	YY_BREAK
/* Preprocessor statement:  RESET_CONDITION(name) */
case 7:
YY_RULE_SETUP
#line 123 "scanner.l"
{
    //printf("RESET_CONDITION\n");
    yy_push_state(PREPROC_RESET_COND, yyscanner);
}
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 127 "scanner.l"
{
    //printf("preproc reset condition '%s'\n", yytext);
    bool success = yyextra->resetPreprocessorCondition(yytext);
    if (!success) {
        SCANNER_ERR((String("Preprocessor: could not reset condition '") +
                    yytext + "' (either not set or a built-in condition).").c_str());
    }
}
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 135 "scanner.l"
{
    //printf("End of RESET_CONDITION\n");
    yy_pop_state(yyscanner);
}
	YY_BREAK
/* Preprocessor conditional statements:

    USE_CODE_IF(name)
      ...
    END_USE_CODE

    and:

    USE_CODE_IF_NOT(name)
      ...
    END_USE_CODE    
 */
case 10:
YY_RULE_SETUP
#line 154 "scanner.l"
{
    //printf("USE_CODE_IF\n");
    yy_push_state(PREPROC_IF, yyscanner);
}
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 158 "scanner.l"
{
    //printf("USE_CODE_IF_NOT\n");
    yy_push_state(PREPROC_IF_NOT, yyscanner);
}
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 162 "scanner.l"
{
    //printf("preproc use code if '%s'\n", yytext);
    yy_pop_state(yyscanner);
    if (yyextra->isPreprocessorConditionSet(yytext))
        yy_push_state(PREPROC_PRE_BODY_USE, yyscanner);
    else
        yy_push_state(PREPROC_PRE_BODY_EAT, yyscanner);
}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 170 "scanner.l"
{
    //printf("preproc use code if not '%s'\n", yytext);
    yy_pop_state(yyscanner);
    if (!yyextra->isPreprocessorConditionSet(yytext))
        yy_push_state(PREPROC_PRE_BODY_USE, yyscanner);
    else
        yy_push_state(PREPROC_PRE_BODY_EAT, yyscanner);
}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 178 "scanner.l"
{
    yy_pop_state(yyscanner);
    yy_push_state(PREPROC_BODY_USE, yyscanner);
}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 182 "scanner.l"
{
    //printf("PREPROCESSOR EAT : \n");
    yy_pop_state(yyscanner);
    yy_push_state(PREPROC_BODY_EAT, yyscanner);
}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 187 "scanner.l"
{
    //printf("-->END_USE_CODE\n");
    yy_pop_state(yyscanner);
}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 191 "scanner.l"
/* eat up code block filtered out by preprocessor */
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 192 "scanner.l"
/* eat up code block filtered out by preprocessor */
	YY_BREAK
/* Language keywords */
case 19:
YY_RULE_SETUP
#line 197 "scanner.l"
return ON;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 198 "scanner.l"
return END;
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 199 "scanner.l"
return NOTE;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 200 "scanner.l"
return INIT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 201 "scanner.l"
return DECLARE;
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 202 "scanner.l"
return WHILE;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 203 "scanner.l"
return IF;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 204 "scanner.l"
return OR;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 205 "scanner.l"
return RELEASE;
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 206 "scanner.l"
return AND;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 207 "scanner.l"
return NOT;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 208 "scanner.l"
return ELSE;
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 209 "scanner.l"
return CONTROLLER;
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 210 "scanner.l"
return CASE;
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 211 "scanner.l"
return SELECT;
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 212 "scanner.l"
return TO;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 213 "scanner.l"
return LE;
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 214 "scanner.l"
return GE;
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 215 "scanner.l"
return CONST_; // note: "CONST" is already defined for C/C++ compilers on Windows by default
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 216 "scanner.l"
return POLYPHONIC;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 217 "scanner.l"
return MOD;
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 219 "scanner.l"
{
    printf("A keyword: %s\n", yytext);
}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 223 "scanner.l"
{ return *yytext; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 225 "scanner.l"
{
    yylval->sValue = strdup(yytext);
    return VARIABLE;
}
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 230 "scanner.l"
{
    yylval->sValue = strdup(yytext);
    return VARIABLE;
}
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 235 "scanner.l"
{
    yylval->sValue = strdup(yytext);
    return IDENTIFIER;
}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 240 "scanner.l"
return ASSIGNMENT;
	YY_BREAK
case 46:
/* rule 46 can match eol */
YY_RULE_SETUP
#line 242 "scanner.l"
{
    //printf("lex: new line %d\n", yylineno, yytext);
    //return LF;
}
	YY_BREAK
case 47:
/* rule 47 can match eol */
YY_RULE_SETUP
#line 247 "scanner.l"
/* eat up comments */
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 249 "scanner.l"
/* eat up whitespace */
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 251 "scanner.l"
/* eat up */
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 253 "scanner.l"
printf( "Unrecognized character: %s\n", yytext );
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 255 "scanner.l"
ECHO;
	YY_BREAK
#line 1833 "lex.InstrScript_.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(PREPROC_BODY_USE):
case YY_STATE_EOF(PREPROC_SET_COND):
case YY_STATE_EOF(PREPROC_RESET_COND):
case YY_STATE_EOF(PREPROC_IF):
case YY_STATE_EOF(PREPROC_IF_NOT):
case YY_STATE_EOF(PREPROC_BODY_EAT):
case YY_STATE_EOF(PREPROC_PRE_BODY_USE):
case YY_STATE_EOF(PREPROC_PRE_BODY_EAT):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * InstrScript_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( InstrScript_wrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of InstrScript_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = yyg->yytext_ptr;
	register int number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					InstrScript_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2 ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			InstrScript_restart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) InstrScript_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yyg->yy_start;

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			yyg->yy_last_accepting_state = yy_current_state;
			yyg->yy_last_accepting_cpos = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 642 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	register int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */
	register char *yy_cp = yyg->yy_c_buf_p;

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		yyg->yy_last_accepting_state = yy_current_state;
		yyg->yy_last_accepting_cpos = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 642 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 641);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

    static void yyunput (int c, register char * yy_bp , yyscan_t yyscanner)
{
	register char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yy_cp = yyg->yy_c_buf_p;

	/* undo effects of setting up yytext */
	*yy_cp = yyg->yy_hold_char;

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		register yy_size_t number_to_move = yyg->yy_n_chars + 2;
		register char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		register char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

    if ( c == '\n' ){
        --yylineno;
    }

	yyg->yytext_ptr = yy_bp;
	yyg->yy_hold_char = *yy_cp;
	yyg->yy_c_buf_p = yy_cp;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			yy_size_t offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					InstrScript_restart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( InstrScript_wrap(yyscanner ) )
						return EOF;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	if ( c == '\n' )
		   
    do{ yylineno++;
        yycolumn=0;
    }while(0)
;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void InstrScript_restart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        InstrScript_ensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            InstrScript__create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	InstrScript__init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	InstrScript__load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void InstrScript__switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		InstrScript_pop_buffer_state();
	 *		InstrScript_push_buffer_state(new_buffer);
     */
	InstrScript_ensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	InstrScript__load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (InstrScript_wrap()) processing, but the only time this flag
	 * is looked at is after InstrScript_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void InstrScript__load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE InstrScript__create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) InstrScript_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in InstrScript__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) InstrScript_alloc(b->yy_buf_size + 2 ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in InstrScript__create_buffer()" );

	b->yy_is_our_buffer = 1;

	InstrScript__init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with InstrScript__create_buffer()
 * @param yyscanner The scanner object.
 */
    void InstrScript__delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		InstrScript_free((void *) b->yy_ch_buf ,yyscanner );

	InstrScript_free((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a InstrScript_restart() or at EOF.
 */
    static void InstrScript__init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	InstrScript__flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then InstrScript__init_buffer was _probably_
     * called from InstrScript_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void InstrScript__flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		InstrScript__load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void InstrScript_push_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	InstrScript_ensure_buffer_stack(yyscanner);

	/* This block is copied from InstrScript__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from InstrScript__switch_to_buffer. */
	InstrScript__load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void InstrScript_pop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	InstrScript__delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		InstrScript__load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void InstrScript_ensure_buffer_stack (yyscan_t yyscanner)
{
	yy_size_t num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)InstrScript_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in InstrScript_ensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)InstrScript_realloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in InstrScript_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE InstrScript__scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) InstrScript_alloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in InstrScript__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	InstrScript__switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to InstrScript_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       InstrScript__scan_bytes() instead.
 */
YY_BUFFER_STATE InstrScript__scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return InstrScript__scan_bytes(yystr,strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to InstrScript_lex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE InstrScript__scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) InstrScript_alloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in InstrScript__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = InstrScript__scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in InstrScript__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

    static void yy_push_state (int  new_state , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( yyg->yy_start_stack_ptr >= yyg->yy_start_stack_depth )
		{
		yy_size_t new_size;

		yyg->yy_start_stack_depth += YY_START_STACK_INCR;
		new_size = yyg->yy_start_stack_depth * sizeof( int );

		if ( ! yyg->yy_start_stack )
			yyg->yy_start_stack = (int *) InstrScript_alloc(new_size ,yyscanner );

		else
			yyg->yy_start_stack = (int *) InstrScript_realloc((void *) yyg->yy_start_stack,new_size ,yyscanner );

		if ( ! yyg->yy_start_stack )
			YY_FATAL_ERROR( "out of memory expanding start-condition stack" );
		}

	yyg->yy_start_stack[yyg->yy_start_stack_ptr++] = YY_START;

	BEGIN(new_state);
}

    static void yy_pop_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( --yyg->yy_start_stack_ptr < 0 )
		YY_FATAL_ERROR( "start-condition stack underflow" );

	BEGIN(yyg->yy_start_stack[yyg->yy_start_stack_ptr]);
}

    static int yy_top_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	return yyg->yy_start_stack[yyg->yy_start_stack_ptr - 1];
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE InstrScript_get_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int InstrScript_get_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int InstrScript_get_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *InstrScript_get_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *InstrScript_get_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
yy_size_t InstrScript_get_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *InstrScript_get_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void InstrScript_set_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void InstrScript_set_lineno (int  line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "InstrScript_set_lineno called with no buffer" );
    
    yylineno = line_number;
}

/** Set the current column.
 * @param line_number
 * @param yyscanner The scanner object.
 */
void InstrScript_set_column (int  column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "InstrScript_set_column called with no buffer" );
    
    yycolumn = column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see InstrScript__switch_to_buffer
 */
void InstrScript_set_in (FILE *  in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = in_str ;
}

void InstrScript_set_out (FILE *  out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = out_str ;
}

int InstrScript_get_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void InstrScript_set_debug (int  bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * InstrScript_get_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void InstrScript_set_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *InstrScript_get_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void InstrScript_set_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* InstrScript_lex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int InstrScript_lex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) InstrScript_alloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* InstrScript_lex_init_extra has the same functionality as InstrScript_lex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to InstrScript_alloc in
 * the yyextra field.
 */

int InstrScript_lex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    InstrScript_set_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) InstrScript_alloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    InstrScript_set_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from InstrScript_lex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = 0;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = (char *) 0;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = (FILE *) 0;
    yyout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * InstrScript_lex_init()
     */
    return 0;
}

/* InstrScript_lex_destroy is for both reentrant and non-reentrant scanners. */
int InstrScript_lex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		InstrScript__delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		InstrScript_pop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	InstrScript_free(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        InstrScript_free(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * InstrScript_lex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    InstrScript_free ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *InstrScript_alloc (yy_size_t  size , yyscan_t yyscanner)
{
	return (void *) malloc( size );
}

void *InstrScript_realloc  (void * ptr, yy_size_t  size , yyscan_t yyscanner)
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void InstrScript_free (void * ptr , yyscan_t yyscanner)
{
	free( (char *) ptr );	/* see InstrScript_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 254 "scanner.l"



namespace LinuxSampler {

void ParserContext::createScanner(std::istream* is) {
   if (scanner) destroyScanner();
   this->is = is;
   InstrScript_lex_init(&scanner);
   InstrScript_set_extra(this,scanner);
}

void ParserContext::destroyScanner() {
   if (!scanner) return;
   InstrScript_lex_destroy(scanner);
   scanner = NULL;
}

} // namespace LinuxSampler

